package
Version:
v0.2.3
Opens a new window with list of versions in this module.
Published: Jul 24, 2025
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type TestEvent struct {
Time string `json:"Time"`
Action string `json:"Action"`
Package string `json:"Package"`
Test string `json:"Test,omitempty"`
Output string `json:"Output,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.